from .tags import CaseTag


class A(CaseTag):
    pass


class Animate(CaseTag):
    pass


class AnimateMotion(CaseTag):
    pass


class AnimateTransform(CaseTag):
    pass


class Circle(CaseTag):
    pass


class ClipPath(CaseTag):
    pass


class Defs(CaseTag):
    pass


class Desc(CaseTag):
    pass


class Ellipse(CaseTag):
    pass


class FeBlend(CaseTag):
    pass


class FeColorMatrix(CaseTag):
    pass


class FeComponentTransfer(CaseTag):
    pass


class FeComposite(CaseTag):
    pass


class FeConvolveMatrix(CaseTag):
    pass


class FeDiffuseLighting(CaseTag):
    pass


class FeDisplacementMap(CaseTag):
    pass


class FeDistantLight(CaseTag):
    pass


class FeDropShadow(CaseTag):
    pass


class FeFlood(CaseTag):
    pass


class FeFuncA(CaseTag):
    pass


class FeFuncB(CaseTag):
    pass


class FeFuncG(CaseTag):
    pass


class FeFuncR(CaseTag):
    pass


class FeGaussianBlur(CaseTag):
    pass


class FeImage(CaseTag):
    pass


class FeMerge(CaseTag):
    pass


class FeMergeNode(CaseTag):
    pass


class FeMorphology(CaseTag):
    pass


class FeOffset(CaseTag):
    pass


class FePointLight(CaseTag):
    pass


class FeSpecularLighting(CaseTag):
    pass


class FeSpotLight(CaseTag):
    pass


class FeTile(CaseTag):
    pass


class FeTurbulence(CaseTag):
    pass


class Filter(CaseTag):
    pass


class ForeignObject(CaseTag):
    pass


class G(CaseTag):
    pass


class Image(CaseTag):
    pass


class Line(CaseTag):
    pass


class LinearGradient(CaseTag):
    pass


class Marker(CaseTag):
    pass


class Mask(CaseTag):
    pass


class Metadata(CaseTag):
    pass


class Mpath(CaseTag):
    pass


class Path(CaseTag):
    pass


class Pattern(CaseTag):
    pass


class Polygon(CaseTag):
    pass


class Polyline(CaseTag):
    pass


class RadialGradient(CaseTag):
    pass


class Rect(CaseTag):
    pass


class Script(CaseTag):
    pass


class Set(CaseTag):
    pass


class Stop(CaseTag):
    pass


class Style(CaseTag):
    pass


class Svg(CaseTag):
    pass


class Switch(CaseTag):
    pass


class Symbol(CaseTag):
    pass


class Text(CaseTag):
    pass


class TextPath(CaseTag):
    pass


class Title(CaseTag):
    pass


class Tspan(CaseTag):
    pass


class Use(CaseTag):
    pass


class View(CaseTag):
    pass
